Sauvons Fabien_le_pendu de la potence!
Jeu du pendu réalisé avec Tkinter.


Exemple d'usage:

    >>> from fabienpendu_lib import pendu
    >>> pendu()

ou dans un terminal utiliser la commande:
```
$ pendu
```
Note: Si non reconnu renseigner le PATH (export PATH=$PATH:~/.local/bin/)
